/**************************************************************************
* Name:      Music_Formater.cpp                                           *
* Purpose:   Code for the Music Formater class                            *
* Author:    Jackie Team (jackie.team@gmail.com)                          *
* Created:   2009-02-12                                                   *
* Copyright: Jackie Team (http://www.musicorganizer.org)                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#ifdef __BORLANDC__
#pragma hdrstop
#endif //__BORLANDC__

#include "Music_Formater.h"

MusicFormater::MusicFormater(wxString f) {
    file = f;

    wxFileName fn(f);
    //Name of the file
    name = fn.GetFullName();
    //Path to the file
    path = fn.GetPath();
    //Extension of the file
    extension = fn.GetExt().Lower();

    choiceBook = NULL;
}

MusicFormater::MusicFormater(wxString f, MonChoicebook* cb) {
    file = f;

    wxFileName fn(f);
    //Name of the file
    name = fn.GetFullName();
    //Path to the file
    path = fn.GetPath();
    //Extension of the file
    extension = fn.GetExt().Lower();

    choiceBook = cb;
}

MusicFormat* MusicFormater::getFormat() {
    if(extension == _T("ogg")) {
        return new MusicFormatOGG(file);
    } else if(extension == _T("flac")) {
        return new MusicFormatFLAC(file);
    }
#ifdef USE_MP4
    else if(extension == _T("m4a") || extension == _T("aac") || extension == _T("m4p")) {
        return new MusicFormatMP4(file);
    }
#endif
    return NULL;
}

MusicFormat* MusicFormater::getFormat(int version) {
    if(extension == _T("mp3")) {
        if (version == 0) //ID3v1
            return new MusicFormatID3V1(file);
        else if (version == 1) //ID3v2
            return new MusicFormatID3V2(file);
    }
    return getFormat();
}

MaListe* MusicFormater::getList() {
    if(extension == _T("ogg")) {
        return choiceBook->getMListeOgg();
    } else if(extension == _T("flac")) {
        return choiceBook->getMListeFlac();
    }
#ifdef USE_MP4
    else if(extension == _T("m4a") || extension == _T("aac") || extension == _T("m4p")) {
        return choiceBook->getMListeMp4();
    }
#endif
    return NULL;
}

MaListe* MusicFormater::getList(int version) {
    if(extension == _T("mp3")) {
        if (version == 0) //ID3v1
            return choiceBook->getMListeV1();
        else if (version == 1) //ID3v2
            return choiceBook->getMListeV2();
    }
    return getList();
}

wxString MusicFormater::getFileExtension() {
    return extension;
}

wxString MusicFormater::getFileName() {
    return name;
}

wxString MusicFormater::getFilePath() {
    return path;
}
